CrdtLwwRegister class

Annotation for Last-Writer-Wins Register merge strategy.

Used for single-value properties where conflicts are resolved by keeping the value with the most recent timestamp.

Constructors

CrdtLwwRegister()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited