FullIndex class

Configuration for the default FullIndex of a root resource.

Controls whether a FullIndex is generated and its parameters. Used as parameter in RootResource.fullIndex.

Constructors

FullIndex({String localName = 'default', RootResourceFetchPolicy policy = RootResourceFetchPolicy.prefetch})
Creates a FullIndex configuration with defaults.
const
FullIndex.disabled()
Disables FullIndex generation for this resource. Use when a resource only has GroupIndex indices.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
Whether FullIndex generation is enabled.
final
localName String
Local name for the FullIndex (default: 'default').
final
policy RootResourceFetchPolicy
Item fetch policy for the FullIndex.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited