MergeIdentifying class

Annotation to mark a property as identifying for a local resource (blank node).

Used to indicate that a property uniquely identifies a local resource, allowing the CRDT system to recognize when two blank nodes represent the same logical entity. This maps to mc:isIdentifying in the merge contract.

Example:

@LocalResource()
class Weblink {
  @RdfProperty(Schema.url)
  @MergeIdentifying()
  @CrdtImmutable()
  final String url;
  // ...
}

Constructors

MergeIdentifying()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited