RootResourceRef class

Inheritance

Constructors

RootResourceRef(Type cls)
const

Properties

fragmentTemplate → String?
Optional template for the fragment identifier to append to the base IRI.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
mapper → MapperRef<IriTermMapper>?
Provides a MapperRef if a custom mapper is specified.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → String?
An optional template string for constructing the IRI.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited