SubIriStrategy class

Inheritance

Constructors

SubIriStrategy(String fragmentTemplate)
const

Properties

fragmentTemplate String?
Optional template for the fragment identifier to append to the base IRI.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
mapper MapperRef<IriTermMapper>?
Provides a MapperRef if a custom mapper is specified.
no setterinherited
providedAs String?
Optional name under which this resource's IRI will be provided to dependent mappers.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String?
An optional template string for constructing IRIs from resource properties.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited