SubIriStrategy constructor

const SubIriStrategy(
  1. String fragmentTemplate
)

Implementation

const SubIriStrategy(String fragmentTemplate)
    : super.withFragment(
        // references the parent resource IRI via the variable we expose in PodIriStrategy
        // so that the subresource IRI can be constructed as {parentResourceIri}#fragment .
        // Note: any fragment will be removed from the parent resource IRI automatically,
        // so it is no problem at all if the parent resource IRI already has a fragment.
        '{+$resourceIriVar}',
        fragmentTemplate,
      );