id property
String
get
id
Stable identifier used to match main/worker handler instances.
Must be unique among storage handlers available in the worker.
Implementation
String get id;
Stable identifier used to match main/worker handler instances.
Must be unique among storage handlers available in the worker.
String get id;