GroupingProperty class
Defines a property used for grouping in a GroupIndex, with optional transforms.
The property IRI identifies which RDF predicate to group by. Optional transforms apply regex transformations before grouping.
Constructors
-
GroupingProperty(IriTerm property, {List<
RegexTransform> transforms = const []}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- property → IriTerm
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transforms
→ List<
RegexTransform> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited