RemoteWorkerHandler class abstract interface

Worker-thread handler for creating remote backend instances.

This interface must be implemented for each remote backend type (Solid Pod, Google Drive, etc.) to provide the worker-thread component of the handler architecture.

The id must match the corresponding RemoteMainHandler.id on the main thread for validation to succeed.

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier matching the main-thread handler.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBackend(BackendWorkerHandlerContext context, SyncEngineConfig config) Future<Backend>
Creates a backend instance for this remote handler.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited