StorageWorkerHandler class abstract
Worker-thread handler for creating local storage instances.
Implementations create and configure the local storage backend (typically Drift/SQLite) that provides offline-first capabilities.
Constructors
Properties
Methods
-
create(
WorkerHandlerContext context, SyncEngineConfig config) → Future< Storage> - Creates a storage instance for the worker thread.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited