WorkerParams class
Constructors
-
WorkerParams({required List<
StorageWorkerHandler> storages, List<RemoteWorkerHandler> remotes = const [], PhysicalTimestampFactory? physicalTimestampFactory, InstallationIdFactory? installationIdFactory, IriTermFactory? iriFactory, RdfCore? rdfCore, Client? httpClient, Fetcher? fetcher, Iterable<String> ? mappingBootstrapSources})
Properties
- fetcher → Fetcher?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpClient → Client?
-
final
- installationIdFactory → InstallationIdFactory?
-
final
- iriFactory → IriTermFactory?
-
final
-
mappingBootstrapSources
→ Iterable<
String> ? -
final
- physicalTimestampFactory → PhysicalTimestampFactory?
-
final
- rdfCore → RdfCore
-
final
-
remotes
→ List<
RemoteWorkerHandler> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storages
→ List<
StorageWorkerHandler> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited